@@ -1,8 +1,15 @@
+# Items related to use of the options package.
+options::define_options(
+  "Show verbose messages.",
+  vb = FALSE
+)
+
+#' @eval options::as_roxygen_docs()
+NULL
+
 .onLoad <- function(libname, pkgname) {
   op <- options()
   op.devtools <- list(
-    # devtools.path = "~/R-dev",
-    # devtools.install.args = "",
     devtools.name = "Rick Gilmore",
     devtools.desc.author = "Rick Gilmore <rog1@psu.edu> [aut, cre]",
     devtools.desc.license = "MIT",
@@ -17,6 +24,3 @@
 
 utils::globalVariables(".data")
 
-#source("R/make_default_request.R")
-#source("R/CONSTANTS.R")
-#DEF_REQ <- databraryr::make_default_request()
\ No newline at end of file
