@@ -1,16 +1,22 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Download Databrary Constants From API.
 #' 
-#' @param vb A Boolean value. If TRUE provides verbose output.
 #' @param rq An `httr2` request object. Defaults to NULL.
 #'
 #' @returns A data frame with the constants.
 #' 
+#' @inheritParams options_params
+#' 
 #' @examples
 #' \donttest{
 #' assign_constants()
 #' }
 #' @export
-assign_constants <- function(vb = FALSE, rq = NULL) {
+assign_constants <- function(vb = options::opt("vb"), rq = NULL) {
   # Check parameter
   assertthat::assert_that(is.logical(vb))
   
@@ -19,6 +25,7 @@ assign_constants <- function(vb = FALSE, rq = NULL) {
   arq <- rq %>%
     httr2::req_url(GET_CONSTANTS)
   
+  if (vb) message("Retrieving constants.")
   resp <- tryCatch(
     httr2::req_perform(arq),
     httr2_error = function(cnd) {
@@ -28,7 +35,7 @@ assign_constants <- function(vb = FALSE, rq = NULL) {
   )
   
   if (is.null(resp)) {
-    if (vb) message("Exiting")
+    message("Cannot access requested resource on Databrary. Exiting.")
     resp
   } else {
     httr2::resp_body_json(resp)
