@@ -1,3 +1,8 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Download Video From Databrary.
 #'
 #' @param asset_id Asset id for target file.
@@ -5,10 +10,11 @@
 #' @param file_name Name for downloaded file.
 #' @param target_dir Directory to save the downloaded file.
 #' Default is a temporary directory given by a call to `tempdir()`.
-#' @param vb A Boolean value. If TRUE provides verbose output.
 #' @param rq An `httr2` request object.
 #'
 #' @returns Full file name to the asset.
+#' 
+#' @inheritParams options_params
 #'
 #' @examples
 #' \donttest{
@@ -24,7 +30,7 @@ download_video <- function(asset_id = 1,
                            session_id = 9807,
                            file_name = tempfile(paste0(session_id, "_", asset_id, "_"), fileext = ".mp4"),
                            target_dir = tempdir(),
-                           vb = FALSE,
+                           vb = options::opt("vb"),
                            rq = NULL) {
   # Check parameters
   assertthat::assert_that(length(asset_id) == 1)
@@ -97,8 +103,7 @@ download_video <- function(asset_id = 1,
   )
   
   if (is.null(resp)) {
-    if (vb)
-      message("Exiting.")
+    message("Cannot access requested resource on Databrary. Exiting.")
     return(resp)
   }
   
