@@ -1,13 +1,19 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Download Zip Archive of All Data in a Volume.
 #'
 #' @param vol_id Volume number.
 #' @param out_dir Directory to save output file.
 #' @param file_name Name for downloaded file, default is 'test.mp4'.
-#' @param vb A Boolean value. If TRUE provides verbose output.
 #' @param rq An `httr2` request object. Default is NULL.
 #'
 #' @returns Full filename of the downloaded file.
 #' 
+#' @inheritParams options_params
+#' 
 #' @examples
 #' \donttest{
 #' \dontrun{
@@ -19,7 +25,7 @@
 download_volume_zip <- function(vol_id = 31,
                                 out_dir = tempdir(),
                                 file_name = "test.zip",
-                                vb = FALSE,
+                                vb = options::opt("vb"),
                                 rq = NULL) {
   # Check parameters
   assertthat::assert_that(length(vol_id) == 1)
@@ -41,8 +47,8 @@ download_volume_zip <- function(vol_id = 31,
   # Handle NULL request
   if (is.null(rq)) {
     if (vb) {
-      message("NULL request object. Will generate default.")
-      message("\nNot logged in. Only public information will be returned.")
+      message("\nNULL request object. Will generate default.")
+      message("Not logged in. Only public information will be returned.")
     }
     rq <- databraryr::make_default_request()
   }
@@ -58,7 +64,7 @@ download_volume_zip <- function(vol_id = 31,
   )
   
   if (is.null(resp)) {
-    if (vb) message("Exiting.")
+    message("Cannot access requested resource on Databrary. Exiting.")
     return(resp)
   }
   
