@@ -1,14 +1,20 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Get Stats About Databrary.
 #'
 #' `get_db_stats` returns basic summary information about
 #' the institutions, people, and data hosted on 'Databrary.org'.
 #'
 #' @param type Type of Databrary report to run "institutions", "people", "data"
-#' @param vb A Boolean value. If TRUE provides verbose output.
 #' @param rq An `httr2` request object.
 #'
 #' @returns A data frame with the requested data or NULL if there is no new information.
 #'
+#' @inheritParams options_params
+#' 
 #' @examples
 #' \donttest{
 #' get_db_stats()
@@ -18,7 +24,7 @@
 #' }
 #' @export
 get_db_stats <- function(type = "stats",
-                         vb = FALSE,
+                         vb = options::opt("vb"),
                          rq = NULL) {
   # Check parameters
   assertthat::assert_that(length(type) == 1)
@@ -46,7 +52,7 @@ get_db_stats <- function(type = "stats",
   
   if (is.null(rq)) {
     if (vb) {
-      message("NULL request object. Will generate default.")
+      message("\nNULL request object. Will generate default.")
       message("Not logged in. Only public information will be returned.")
     }
     rq <- databraryr::make_default_request()
@@ -64,8 +70,7 @@ get_db_stats <- function(type = "stats",
   )
   
   if (is.null(resp)) {
-    if (vb)
-      message("Exiting.")
+    message("Cannot access requested resource on Databrary. Exiting.")
     return(resp)
   }
   
