@@ -1,15 +1,21 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Download Information About a Party on Databrary as JSON
 #'
 #' @param party_id An integer. The party number to retrieve information about.
 #' @param parents_children_access A logical value. If TRUE (the default), 
 #' returns _all_ of the data about the party. If FALSE, only a minimum amount
 #' of information about the party is returned.
-#' @param vb A logical value if TRUE returns verbose output.
 #' @param rq An `httr2`-style request object. If NULL, then a new request will
 #' be generated using `make_default_request()`.
 #'
 #' @returns A nested list with information about the party. 
 #' This can be readily parsed by other functions.
+#' 
+#' @inheritParams options_params
 #'
 #' @examples
 #' \donttest{
@@ -20,7 +26,7 @@
 #' @export
 get_party_by_id <- function(party_id = 6,
                             parents_children_access = TRUE,
-                            vb = FALSE,
+                            vb = options::opt("vb"),
                             rq = NULL) {
   # Check parameters
   assertthat::assert_that(is.numeric(party_id))
@@ -37,7 +43,7 @@ get_party_by_id <- function(party_id = 6,
   
   if (is.null(rq)) {
     if (vb) {
-      message("NULL request object. Will generate default.")
+      message("\nNULL request object. Will generate default.")
       message("Not logged in. Only public information will be returned.")  
     }
     rq <- databraryr::make_default_request()
@@ -50,6 +56,8 @@ get_party_by_id <- function(party_id = 6,
   }
   prq <- rq %>%
     httr2::req_url(sprintf(endpoint, party_id))
+
+    if (vb) message("Querying API for party id ", party_id, ".")
   resp <- tryCatch(
     httr2::req_perform(prq),
     httr2_error = function(cnd) {
@@ -59,9 +67,10 @@ get_party_by_id <- function(party_id = 6,
     }
   )
   
-  if (!is.null(resp)) {
-    httr2::resp_body_json(resp)
+  if (is.null(resp)) {
+    message("Cannot access requested resource on Databrary. Exiting.")
+    return(resp)
   } else {
-    resp
+    httr2::resp_body_json(resp) 
   }
 }
