@@ -1,22 +1,27 @@
+#' @eval options::as_params()
+#' @name options_params
+#'
+NULL
+
 #' Report Information About A Funder.
 #'
 #' @param search_string String to search.
-#' @param vb A Boolean value. If TRUE provides verbose output.
-#' @param rq An `httr2` request object. Default is NULL. 
+#' @param rq An `httr2` request object. Default is NULL.
 #'
 #' @returns A data frame with information about the funder.
-#' 
+#'
+#' @inheritParams options_params
+#'
 #' @examples
 #' \donttest{
 #' search_for_funder("national+science+foundation")
 #' }
-#' 
+#'
 #' @export
 search_for_funder <-
   function(search_string = "national+science+foundation",
-           vb = FALSE,
+           vb = options::opt("vb"),
            rq = NULL) {
-    
     # Check parameters
     assertthat::assert_that(length(search_string) == 1)
     assertthat::assert_that(is.character(search_string))
@@ -30,13 +35,15 @@ search_for_funder <-
     if (is.null(rq)) {
       if (vb) {
         message("NULL request object. Will generate default.")
-        message("Not logged in. Only public information will be returned.")  
+        message("Not logged in. Only public information will be returned.")
       }
       rq <- databraryr::make_default_request()
     }
     rq <- rq %>%
       httr2::req_url(sprintf(QUERY_VOLUME_FUNDER, search_string))
     
+    if (vb)
+      message("Retrieving data for funder string '", search_string, "'.")
     resp <- tryCatch(
       httr2::req_perform(rq),
       httr2_error = function(cnd) {
@@ -46,10 +53,11 @@ search_for_funder <-
     
     if (vb)
       message('search_for_keywords()...')
-
-    if (!is.null(resp)) {
-      httr2::resp_body_json(resp) %>% as.data.frame()
+    
+    if (is.null(resp)) {
+      message("Cannot access requested resource on Databrary. Exiting.")
+      return(resp)
     } else {
-      resp
+      httr2::resp_body_json(resp) %>% as.data.frame()
     }
   }
