@@ -1,10 +1,16 @@
+#' @eval options::as_params()
+#' @name options_params
+#' 
+NULL
+
 #' Search For Tags on Volumes or Sessions.
 #'
 #' @param search_string String to search.
-#' @param vb A Boolean value. If TRUE provides verbose output.
 #' @param rq An `httr2` request object. Default is NULL.
 #'
 #' @returns An array of tags that match the tag_string.
+#' 
+#' @inheritParams options_params
 #'
 #' @examples
 #' \dontrun{
@@ -14,7 +20,7 @@
 #' @export
 search_for_tags <-
   function(search_string = "ICIS",
-           vb = FALSE,
+           vb = options::opt("vb"),
            rq = NULL) {
     # Check parameters
     assertthat::assert_that(length(search_string) == 1)
